@@ -1,9 +1,9 @@
 ##############################################################################
 #
-# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
-# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
@@ -12,7 +12,7 @@
 ##############################################################################
 """Access control support
 
-$Id: Role.py 73418 2007-03-21 11:48:43Z mj $
+$Id: Role.py 73389 2007-03-20 09:03:57Z mj $
 """
 from cgi import escape
 
@@ -20,7 +20,9 @@ from Globals import DTMLFile, MessageDialog, Dictionary
 from Acquisition import Implicit, Acquired, aq_get
 import Globals, ExtensionClass, PermissionMapping, Products
 from App.Common import aq_base
+from zope.interface import implements
 
+from interfaces import IRoleManager
 from Permission import Permission
 from requestmethod import postonly
 
@@ -38,6 +40,8 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
 
     """An object that has configurable permissions"""
 
+    implements(IRoleManager)
+
     __ac_permissions__=(
         ('Change permissions',
          ('manage_access', 'permission_settings',
@@ -132,6 +136,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
                              help_topic='Security_Manage-Role.stx',
                              help_product='OFSP')
 
+    @postonly
     def manage_role(self, role_to_manage, permissions=[], REQUEST=None):
         """Change the permissions given to the given role.
         """
@@ -142,13 +147,13 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
             p.setRole(role_to_manage, name in permissions)
 
         if REQUEST is not None: return self.manage_access(REQUEST)
-    manage_role = postonly(manage_role)
 
     manage_acquiredForm=DTMLFile('dtml/acquiredEdit', globals(),
                                  management_view='Security',
                                  help_topic='Security_Manage-Acquisition.stx',
                                  help_product='OFSP')
 
+    @postonly
     def manage_acquiredPermissions(self, permissions=[], REQUEST=None):
         """Change the permissions that acquire.
         """
@@ -162,13 +167,13 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
             else:                   p.setRoles(tuple(roles))
 
         if REQUEST is not None: return self.manage_access(REQUEST)
-    manage_acquiredPermissions = postonly(manage_acquiredPermissions)
 
     manage_permissionForm=DTMLFile('dtml/permissionEdit', globals(),
                                    management_view='Security',
                                    help_topic='Security_Manage-Permission.stx',
                                    help_product='OFSP')
 
+    @postonly
     def manage_permission(self, permission_to_manage,
                           roles=[], acquire=0, REQUEST=None):
         """Change the settings for the given permission.
@@ -191,7 +196,6 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         raise ValueError, (
             "The permission <em>%s</em> is invalid." %
                 escape(permission_to_manage))
-    manage_permission = postonly(manage_permission)
 
     _normal_manage_access=DTMLFile('dtml/access', globals())
 
@@ -206,6 +210,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         else:
             return apply(self._normal_manage_access,(), kw)
 
+    @postonly
     def manage_changePermissions(self, REQUEST):
         """Change all permissions settings, called by management screen.
         """
@@ -236,7 +241,6 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
             title  ='Success!',
             message='Your changes have been saved',
             action ='manage_access')
-    manage_changePermissions = postonly(manage_changePermissions)
 
     def permissionsOfRole(self, role):
         """Used by management screen.
@@ -354,6 +358,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         dict=self.__ac_local_roles__ or {}
         return tuple(dict.get(userid, []))
 
+    @postonly
     def manage_addLocalRoles(self, userid, roles, REQUEST=None):
         """Set local roles for a user."""
         if not roles:
@@ -370,8 +375,8 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         if REQUEST is not None:
             stat='Your changes have been saved.'
             return self.manage_listLocalRoles(self, REQUEST, stat=stat)
-    manage_addLocalRoles = postonly(manage_addLocalRoles)
 
+    @postonly
     def manage_setLocalRoles(self, userid, roles, REQUEST=None):
         """Set local roles for a user."""
         if not roles:
@@ -384,8 +389,8 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         if REQUEST is not None:
             stat='Your changes have been saved.'
             return self.manage_listLocalRoles(self, REQUEST, stat=stat)
-    manage_setLocalRoles = postonly(manage_setLocalRoles)
 
+    @postonly
     def manage_delLocalRoles(self, userids, REQUEST=None):
         """Remove all local roles for a user."""
         dict=self.__ac_local_roles__
@@ -398,7 +403,6 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         if REQUEST is not None:
             stat='Your changes have been saved.'
             return self.manage_listLocalRoles(self, REQUEST, stat=stat)
-    manage_delLocalRoles = postonly(manage_delLocalRoles)
 
     #------------------------------------------------------------
 
@@ -477,6 +481,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
 
         return self.manage_access(REQUEST)
 
+    @postonly
     def _addRole(self, role, REQUEST=None):
         if not role:
             return MessageDialog(
@@ -493,8 +498,8 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         self.__ac_roles__=tuple(data)
         if REQUEST is not None:
             return self.manage_access(REQUEST)
-    _addRole = postonly(_addRole)
 
+    @postonly
     def _delRoles(self, roles, REQUEST=None):
         if not roles:
             return MessageDialog(
@@ -508,7 +513,6 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         self.__ac_roles__=tuple(data)
         if REQUEST is not None:
             return self.manage_access(REQUEST)
-    _delRoles = postonly(_delRoles)
 
     def _has_user_defined_role(self, role):
         return role in self.__ac_roles__
