@@ -4,7 +4,7 @@
  All Rights Reserved.
 
  This software is subject to the provisions of the Zope Public License,
- Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+ Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
  WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
@@ -14,10 +14,10 @@
 static char _extensionclass_module_documentation[] = 
 "ExtensionClass\n"
 "\n"
-"$Id: _ExtensionClass.c 30412 2005-05-19 08:35:58Z andreasjung $\n"
+"$Id: _ExtensionClass.c 40222 2005-11-18 15:46:28Z andreasjung $\n"
 ;
 
-#include "ExtensionClass.h"
+#include "ExtensionClass/ExtensionClass.h"
 
 #define EC PyTypeObject
 
