@@ -12,9 +12,9 @@
 ##############################################################################
 """ Basic ZPublisher request management.
 
-$Id: BaseRequest.py 41705 2006-02-19 18:44:27Z shh $
+$Id: BaseRequest.py 72974 2007-03-04 20:50:42Z mj $
 """
-from urllib import quote
+from urllib import quote as urllib_quote
 import xmlrpc
 from zExceptions import Forbidden
 
@@ -23,6 +23,10 @@ from zope.app.publication.interfaces import EndRequestEvent
 
 UNSPECIFIED_ROLES=''
 
+def quote(text):
+    # quote url path segments, but leave + and @ intact
+    return urllib_quote(text, '/+@')
+
 try:
     from ExtensionClass import Base
     class RequestContainer(Base):
